@@ -21,17 +21,18 @@
  */
 
 #include <stdarg.h>
-#include <stdio.h>
 #include <sys/wait.h>
 #include <unistd.h>
 #include <limits.h>
+#include <fcntl.h>
 
 #include "util.h"
+#include "tokenize.h"
 
-/** Print error and exit with EXIT_FAILURE code
+/** Print error and exit with EXIT_FAILURE code.
  */
 void
-_eprint(int line, const char *fct, const char *fmt, ...)
+_fatal(int line, const char *fct, const char *fmt, ...)
 {
     va_list ap;
 
@@ -39,10 +40,11 @@ _eprint(int line, const char *fct, const char *fmt, ...)
     fprintf(stderr, "E: awesome: %s:%d: ", fct, line);
     vfprintf(stderr, fmt, ap);
     va_end(ap);
+    fprintf(stderr, "\n");
     exit(EXIT_FAILURE);
 }
 
-/** Print error message on stderr
+/** Print error message on stderr.
  */
 void
 _warn(int line, const char *fct, const char *fmt, ...)
@@ -52,85 +54,122 @@ _warn(int line, const char *fct, const char *fmt, ...)
     fprintf(stderr, "W: awesome: %s:%d: ", fct, line);
     vfprintf(stderr, fmt, ap);
     va_end(ap);
-}
-
-/** Compute a value from a string containing
- * an absolute or a relative number. If relative,
- * add it to current_value.
- * \param arg the string with the number
- * \param current_value value to add the number if it's relative
- * \return new value
- */
-double
-compute_new_value_from_arg(const char *arg, double current_value)
-{
-    double delta;
-
-    if(arg && sscanf(arg, "%lf", &delta) == 1)
-    {
-        if(arg[0] == '+' || arg[0] == '-')
-            current_value += delta;
-        else
-            current_value = delta;
-    }
-
-    return current_value;
+    fprintf(stderr, "\n");
 }
 
 /** Lookup for a function pointer from its name
- * in the given name_func_link_t list
- * \param funcname Function name
- * \param list Function and name link list
- * \return function pointer
+ * in the given name_func_link_t list.
+ * \param funcname Function name.
+ * \param len The function name length.
+ * \param list Function and name link list.
+ * \return Function pointer.
  */
 void *
-name_func_lookup(const char *funcname, const name_func_link_t *list)
+name_func_lookup(const char *funcname, size_t len, const name_func_link_t *list)
 {
     int i;
 
     if(funcname && list)
         for(i = 0; list[i].name; i++)
-            if(!a_strcmp(funcname, list[i].name))
+            if(len == list[i].len && !a_strcmp(funcname, list[i].name))
                 return list[i].func;
 
     return NULL;
 }
 
-Position
-position_get_from_str(const char *pos)
+/** Lookup for a function name from its pointer
+ * in the given name_func_link_t list.
+ * \param funcp Function pointer.
+ * \param list Function and name link list.
+ * \return Name of the function.
+ */
+const char *
+name_func_rlookup(void * funcp, const name_func_link_t *list)
 {
-    if(!a_strncmp(pos, "top", 3))
-        return Top;
-    else if(!a_strncmp(pos, "bottom", 6))
-        return Bottom;
-    else if(!a_strncmp(pos, "right", 5))
-        return Right;
-    else if(!a_strncmp(pos, "left", 4))
-        return Left;
-    else if(!a_strncmp(pos, "auto", 4))
-        return Auto;
-    return Off;
+    int i;
+    
+    if(funcp && list)
+        for(i = 0; list[i].name; i++)
+            if(funcp == list[i].func)
+                return list[i].name;
+
+    return NULL;
 }
 
-/** \brief safe limited strdup.
- *
- * Copies at most min(<tt>n-1</tt>, \c l) characters from \c src into a newly
- * allocated buffer, always adding a final \c \\0, and returns that buffer.
- *
- * \param[in]  src      source string.
- * \param[in]  l        maximum number of chars to copy.
- *
- * \return a newly allocated buffer containing the first \c l chars of \c src.
-*/
-char* a_strndup(const char* src, ssize_t l)
+/** Get a position type from a string.
+ * \param pos The position.
+ * \param len The string length, -1 if unknown.
+ * \return A position.
+ */
+position_t
+position_fromstr(const char *pos, ssize_t len)
 {
-    char* _tmpStr = p_new(char, l + 1);
-    if (_tmpStr)
+    switch(a_tokenize(pos, len))
     {
-        a_strncpy(_tmpStr, l + 1, src, l);
-        _tmpStr[l] = 0;
+      default:
+        return Top;
+      case A_TK_BOTTOM:
+        return Bottom;
+      case A_TK_RIGHT:
+        return Right;
+      case A_TK_LEFT:
+        return Left;
+      case A_TK_FLOATING:
+        return Floating;
+    }
+}
+
+/** Convert a position type to a string.
+ * \param p The position.
+ * \return A position string.
+ */
+const char *
+position_tostr(position_t p)
+{
+    switch(p)
+    {
+      case Top:      return "top";
+      case Bottom:   return "bottom";
+      case Right:    return "right";
+      case Left:     return "left";
+      case Floating: return "floating";
+      default:       return NULL;
+    }
+}
+
+/** Get a orientation type from a string.
+ * \param pos The orientation.
+ * \param len The string length, -1 if unknown.
+ * \return A orientation.
+ */
+orientation_t
+orientation_fromstr(const char *pos, ssize_t len)
+{
+    switch(a_tokenize(pos, len))
+    {
+      default:
+        return North;
+      case A_TK_SOUTH:
+        return South;
+      case A_TK_EAST:
+        return East;
+    }
+}
+
+/** Convert a orientation type to a string.
+ * \param p The orientation.
+ * \return A orientation string.
+ */
+const char *
+orientation_tostr(orientation_t p)
+{
+    switch(p)
+    {
+      case North: return "north";
+      case South: return "south";
+      case East:  return "east";
+      default:    return NULL;
     }
-    return _tmpStr;
 }
 
 /** \brief safe limited strcpy.
@@ -145,7 +184,8 @@ char* a_strndup(const char* src, ssize_t l)
  *
  * \return minimum of  \c src \e length and \c l.
 */
-ssize_t a_strncpy(char *dst, ssize_t n, const char *src, ssize_t l)
+ssize_t
+a_strncpy(char *dst, ssize_t n, const char *src, ssize_t l)
 {
     ssize_t len = MIN(a_strlen(src), l);
 
@@ -170,7 +210,8 @@ ssize_t a_strncpy(char *dst, ssize_t n, const char *src, ssize_t l)
  * \return \c src \e length. If this value is \>= \c n then the copy was
  *         truncated.
  */
-ssize_t a_strcpy(char *dst, ssize_t n, const char *src)
+ssize_t
+a_strcpy(char *dst, ssize_t n, const char *src)
 {
     ssize_t len = a_strlen(src);
 
@@ -183,4 +224,19 @@ ssize_t a_strcpy(char *dst, ssize_t n, const char *src)
 
     return len;
 }
+
+/** Execute a command and replace the current process.
+ * \param cmd The command to execute.
+ */
+void
+a_exec(const char *cmd)
+{
+    static const char *shell = NULL;
+
+    if(!shell && !(shell = getenv("SHELL")))
+        shell = "/bin/sh";
+
+    execl(shell, shell, "-c", cmd, NULL);
+}
+
 // vim: filetype=c:expandtab:shiftwidth=4:tabstop=8:softtabstop=4:encoding=utf-8:textwidth=80
