@@ -23,42 +23,86 @@
 #ifndef AWESOME_COMMON_UTIL_H
 #define AWESOME_COMMON_UTIL_H
 
+#define _GNU_SOURCE
+
 #include <string.h>
 #include <stdlib.h>
+#include <stdbool.h>
+#include <stdarg.h>
+#include <assert.h>
+#include <stdio.h>
+
+#if !(defined (__FreeBSD__) || defined(__OpenBSD__))
+#include <alloca.h>
+#endif
+
+typedef enum
+{
+    East,
+    South,
+    North,
+} orientation_t;
 
 /** A list of possible position, not sex related */
 typedef enum
 {
-    Off = 0,
     Top,
     Bottom,
     Right,
     Left,
-    Auto
-} Position;
+    Floating
+} position_t;
 
 /** Link a name to a function */
 typedef struct
 {
     const char *name;
+    size_t len;
     void *func;
 } name_func_link_t;
 
 /** \brief replace \c NULL strings with emtpy strings */
 #define NONULL(x)       (x ? x : "")
 
+#define DO_NOTHING(...)
+
 #undef MAX
 #undef MIN
 #define MAX(a,b) ((a) < (b) ? (b) : (a))
 #define MIN(a,b) ((a) < (b) ? (a) : (b))
 
+#define unsigned_subtract(a, b)  \
+    do {                         \
+        if (b > a)               \
+            a = 0;               \
+        else                     \
+            a -= b;              \
+    } while (0)
+
 #define ssizeof(foo)            (ssize_t)sizeof(foo)
 #define countof(foo)            (ssizeof(foo) / ssizeof(foo[0]))
 
+#define p_alloca(type, count)                                \
+        ((type *)memset(alloca(sizeof(type) * (count)),      \
+                        0, sizeof(type) * (count)))
+
+#define p_alloc_nr(x)           (((x) + 16) * 3 / 2)
 #define p_new(type, count)      ((type *)xmalloc(sizeof(type) * (count)))
 #define p_clear(p, count)       ((void)memset((p), 0, sizeof(*(p)) * (count)))
 #define p_realloc(pp, count)    xrealloc((void*)(pp), sizeof(**(pp)) * (count))
 #define p_dup(p, count)         xmemdup((p), sizeof(*(p)) * (count))
+#define p_grow(pp, goalnb, allocnb)                  \
+    do {                                             \
+        if ((goalnb) > *(allocnb)) {                 \
+            if (p_alloc_nr(*(allocnb)) < (goalnb)) { \
+                *(allocnb) = (goalnb);               \
+            } else {                                 \
+                *(allocnb) = p_alloc_nr(*(allocnb)); \
+            }                                        \
+            p_realloc(pp, *(allocnb));               \
+        }                                            \
+    } while (0)
+
 
 #ifdef __GNUC__
 
@@ -69,6 +113,9 @@ typedef struct
         *__ptr = NULL;                             \
     } while(0)
 
+#define likely(expr)    __builtin_expect(!!(expr), 1)
+#define unlikely(expr)  __builtin_expect((expr), 0)
+
 #else
 
 #define p_delete(mem_p)                            \
@@ -78,6 +125,9 @@ typedef struct
         *(void **)__ptr = NULL;                    \
     } while (0)
 
+#define likely(expr)    expr
+#define unlikely(expr)  expr
+
 #endif
 
 static inline void * __attribute__ ((malloc)) xmalloc(ssize_t size)
@@ -108,6 +158,11 @@ xrealloc(void **ptr, ssize_t newsize)
     }
 }
 
+/** Duplicate a memory zone.
+ * \param src The source.
+ * \param size The source size.
+ * \return The memory address of the copy.
+ */
 static inline void *xmemdup(const void *src, ssize_t size)
 {
     return memcpy(xmalloc(size), src, size);
@@ -160,12 +215,37 @@ static inline ssize_t a_strnlen(const char *s, ssize_t n)
  * \param[in] s the string to duplicate.
  * \return a pointer to the duplicated string.
  */
-static inline char *a_strdup(const char *s)
+static inline
+char *a_strdup(const char *s)
 {
     ssize_t len = a_strlen(s);
     return len ? p_dup(s, len + 1) : NULL;
 }
 
+/** \brief safe limited strdup.
+ *
+ * Copies at most min(<tt>n-1</tt>, \c l) characters from \c src into a newly
+ * allocated buffer, always adding a final \c \\0, and returns that buffer.
+ *
+ * \warning when s is \c "" or l is 0, it returns NULL !
+ *
+ * \param[in]  s        source string.
+ * \param[in]  l        maximum number of chars to copy.
+ * \return a newly allocated buffer containing the first \c l chars of \c src.
+*/
+static inline
+char * a_strndup(const char *s, ssize_t l)
+{
+    ssize_t len = MIN(a_strlen(s), l);
+    if(len)
+    {
+        char *p = p_dup(s, len + 1);
+        p[len] = '\0';
+        return p;
+    }
+    return NULL;
+}
+
 /** \brief \c NULL resistant strcmp.
  * \param[in]  a     the first string.
  * \param[in]  b     the second string.
@@ -174,7 +254,7 @@ static inline char *a_strdup(const char *s)
  */
 static inline int a_strcmp(const char *a, const char *b)
 {
-        return strcmp(NONULL(a), NONULL(b));
+    return strcmp(NONULL(a), NONULL(b));
 }
 
 /** \brief \c NULL resistant strcasecmp.
@@ -202,7 +282,6 @@ static inline int a_strncmp(const char *a, const char *b, ssize_t n)
 
 ssize_t a_strncpy(char *dst, ssize_t n, const char *src, ssize_t l) __attribute__((nonnull(1)));
 ssize_t a_strcpy(char *dst, ssize_t n, const char *src) __attribute__((nonnull(1)));
-char* a_strndup(const char *src, ssize_t l) __attribute__((nonnull(1)));
 
 /** \brief safe strcat.
  *
@@ -239,10 +318,10 @@ a_strncat(char *dst, ssize_t n, const char *src, ssize_t l)
     return dlen + a_strncpy(dst + dlen, n - dlen, src, l);
 }
 
-#define eprint(string, ...) _eprint(__LINE__, \
-                                    __FUNCTION__, \
-                                    string, ## __VA_ARGS__)
-void _eprint(int, const char *, const char *, ...)
+#define fatal(string, ...) _fatal(__LINE__, \
+                                  __FUNCTION__, \
+                                  string, ## __VA_ARGS__)
+void _fatal(int, const char *, const char *, ...)
     __attribute__ ((noreturn)) __attribute__ ((format(printf, 3, 4)));
 
 #define warn(string, ...) _warn(__LINE__, \
@@ -251,9 +330,13 @@ void _eprint(int, const char *, const char *, ...)
 void _warn(int, const char *, const char *, ...)
     __attribute__ ((format(printf, 3, 4)));
 
-Position position_get_from_str(const char *);
-double compute_new_value_from_arg(const char *, double);
-void *name_func_lookup(const char *, const name_func_link_t *);
+position_t position_fromstr(const char *, ssize_t);
+const char * position_tostr(position_t);
+orientation_t orientation_fromstr(const char *, ssize_t);
+const char * orientation_tostr(orientation_t);
+void *name_func_lookup(const char *, size_t, const name_func_link_t *);
+const char * name_func_rlookup(void *, const name_func_link_t *);
+void a_exec(const char *);
 
 #endif
 // vim: filetype=c:expandtab:shiftwidth=4:tabstop=8:softtabstop=4:encoding=utf-8:textwidth=80
