@@ -22,24 +22,20 @@
 #ifndef AWESOME_EVENT_H
 #define AWESOME_EVENT_H
 
-#include <X11/Xlib.h>
+#include "wibox.h"
+#include "layout.h"
+#include "client.h"
 
-#define CLEANMASK(mask)      (mask & ~(globalconf.numlockmask | LockMask))
+static inline int
+awesome_refresh(void)
+{
+    layout_refresh();
+    wibox_refresh();
+    client_stack_refresh();
+    return xcb_flush(globalconf.connection);
+}
 
-void event_handle_buttonpress(XEvent *);
-void event_handle_configurerequest(XEvent *);
-void event_handle_configurenotify(XEvent *);
-void event_handle_destroynotify(XEvent *);
-void event_handle_enternotify(XEvent *);
-void event_handle_expose(XEvent *);
-void event_handle_keypress(XEvent *);
-void event_handle_mappingnotify(XEvent *);
-void event_handle_maprequest(XEvent *);
-void event_handle_propertynotify(XEvent *);
-void event_handle_unmapnotify(XEvent *);
-void event_handle_shape(XEvent *);
-void event_handle_randr_screen_change_notify(XEvent *);
-void event_handle_clientmessage(XEvent *);
+void a_xcb_set_event_handlers(void);
 
 #endif
 // vim: filetype=c:expandtab:shiftwidth=4:tabstop=8:softtabstop=4:encoding=utf-8:textwidth=80
