@@ -1,7 +1,7 @@
 /*
  * ewmh.h - EWMH header
  *
- * Copyright © 2007-2008 Julien Danjou <julien@danjou.info>
+ * Copyright © 2007-2009 Julien Danjou <julien@danjou.info>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -24,23 +24,23 @@
 
 #include "structs.h"
 
-typedef struct
-{
-    int height;
-    int width;
-    unsigned char *image;
-} NetWMIcon;
-
-void ewmh_init_atoms(void);
-void ewmh_set_supported_hints(int);
+void ewmh_init(int);
 void ewmh_update_net_client_list(int);
 void ewmh_update_net_numbers_of_desktop(int);
 void ewmh_update_net_current_desktop(int);
 void ewmh_update_net_desktop_names(int);
 void ewmh_update_net_active_window(int);
-void ewmh_process_client_message(XClientMessageEvent *);
-void ewmh_check_client_hints(Client *);
-NetWMIcon * ewmh_get_window_icon(Window);
+int ewmh_process_client_message(xcb_client_message_event_t *);
+void ewmh_update_net_client_list_stacking(int);
+void ewmh_client_check_hints(client_t *);
+void ewmh_client_update_hints(client_t *);
+void ewmh_client_update_desktop(client_t *);
+void ewmh_update_workarea(int);
+void ewmh_process_client_strut(client_t *, xcb_get_property_reply_t *);
+void ewmh_update_client_strut(client_t *c);
+xcb_get_property_cookie_t ewmh_window_icon_get_unchecked(xcb_window_t);
+int ewmh_window_icon_from_reply(xcb_get_property_reply_t *);
+int ewmh_window_icon_get_reply(xcb_get_property_cookie_t);
 
 #endif
 // vim: filetype=c:expandtab:shiftwidth=4:tabstop=8:softtabstop=4:encoding=utf-8:textwidth=80
