@@ -22,28 +22,7 @@
 #ifndef AWESOME_LAYOUT_H
 #define AWESOME_LAYOUT_H
 
-#include <X11/Xlib.h>
-
-#include "uicb.h"
-#include "common/list.h"
-#include "common/util.h"
-
-typedef void (LayoutArrange)(int);
-
-typedef struct Layout Layout;
-struct Layout
-{
-    char *image;
-    LayoutArrange *arrange;
-    Layout *prev, *next;
-};
-
-DO_SLIST(Layout, layout, p_delete)
-
-int layout_refresh(void);
-Layout * layout_get_current(int);
-
-Uicb uicb_tag_setlayout;
+void layout_refresh(void);
 
 #endif
 // vim: filetype=c:expandtab:shiftwidth=4:tabstop=8:softtabstop=4:encoding=utf-8:textwidth=80
