@@ -22,15 +22,42 @@
 #ifndef AWESOME_SCREEN_H
 #define AWESOME_SCREEN_H
 
-#include "structs.h"
+#include "wibox.h"
 
-area_t screen_get_area(int, Statusbar *, Padding *);
-area_t get_display_area(int, Statusbar *, Padding *);
+struct a_screen
+{
+    /** Screen geometry */
+    area_t geometry;
+    /** true if we need to arrange() */
+    bool need_arrange;
+    /** Tag list */
+    tag_array_t tags;
+    /** Wiboxes */
+    wibox_array_t wiboxes;
+    /** Padding */
+    padding_t padding;
+    /** Window that contains the systray */
+    struct
+    {
+        xcb_window_t window;
+        /** Systray window parent */
+        xcb_window_t parent;
+    } systray;
+    /** Previously focused client */
+    client_t *prev_client_focus;
+    /** Focused client */
+    client_t *client_focus;
+    /** The monitor of startup notifications */
+    SnMonitorContext *snmonitor;
+};
+ARRAY_FUNCS(screen_t, screen, DO_NOTHING)
+
+void screen_scan(void);
+screen_t *screen_getbycoord(screen_t *, int, int);
+area_t screen_area_get(screen_t *, wibox_array_t *, padding_t *, bool);
+area_t display_area_get(int, wibox_array_t *, padding_t *);
 int screen_virttophys(int);
-void move_client_to_screen(Client *, int, Bool);
-
-Uicb uicb_screen_focus;
-Uicb uicb_client_movetoscreen;
+void screen_client_moveto(client_t *, screen_t *, bool, bool);
 
 #endif
 // vim: filetype=c:expandtab:shiftwidth=4:tabstop=8:softtabstop=4:encoding=utf-8:textwidth=80
