@@ -22,35 +22,33 @@
 #ifndef AWESOME_TAG_H
 #define AWESOME_TAG_H
 
-#include "structs.h"
+#include "client.h"
 
-/** Check if a client is tiled */
-#define IS_TILED(client, screen)            (client && !client->isfloating && !client->ismax && client_isvisible(client, screen))
+/** Tag type */
+struct tag
+{
+    /** Lua references count */
+    luaA_ref_array_t refs;
+    /** Tag name */
+    char *name;
+    /** Screen */
+    screen_t *screen;
+    /** true if selected */
+    bool selected;
+    /** clients in this tag */
+    client_array_t clients;
+};
 
-Tag * tag_new(const char *, Layout *, double, int, int);
-void tag_view(Tag *, Bool);
-void tag_view_byindex(int, int, Bool);
-void tag_push_to_screen(Tag *, int);
-Tag ** tags_get_current(int);
-void tag_client(Client *, Tag *);
-void untag_client(Client *, Tag *);
-Bool is_client_tagged(Client *, Tag *);
-void tag_client_with_rule(Client *, Rule *r);
-void tag_client_with_current_selected(Client *);
-void tag_view_only_byindex(int, int);
-void tag_append_to_screen(Tag *, int);
+tag_t **tags_get_current(screen_t *);
+void tag_client(client_t *);
+void untag_client(client_t *, tag_t *);
+bool is_client_tagged(client_t *, tag_t *);
+void tag_view_only_byindex(screen_t *, int);
+void tag_append_to_screen(screen_t *);
+void tag_unref_simplified(tag_t **);
 
-Uicb uicb_client_tag;
-Uicb uicb_client_toggletag;
-Uicb uicb_tag_toggleview;
-Uicb uicb_tag_view;
-Uicb uicb_tag_prev_selected;
-Uicb uicb_tag_viewnext;
-Uicb uicb_tag_viewprev;
-Uicb uicb_tag_create;
-
-DO_SLIST(Tag, tag, p_delete)
-DO_SLIST(tag_client_node_t, tag_client_node, p_delete)
+ARRAY_FUNCS(tag_t *, tag, tag_unref_simplified)
+LUA_OBJECT_FUNCS(tag_t, tag, "tag")
 
 #endif
 // vim: filetype=c:expandtab:shiftwidth=4:tabstop=8:softtabstop=4:encoding=utf-8:textwidth=80
