@@ -22,16 +22,19 @@
 #ifndef AWESOME_WINDOW_H
 #define AWESOME_WINDOW_H
 
-#include "common/draw.h"
+#include "structs.h"
 
-int window_setstate(Window, long);
-long window_getstate(Window);
-Status window_configure(Window, area_t, int);
-void window_grabbuttons(Window, int);
-void window_root_grabbuttons(int);
-void window_root_grabkeys(int);
-void window_setshape(Window, int);
-int window_settrans(Window, double);
+void window_state_set(xcb_window_t, long);
+xcb_get_property_cookie_t window_state_get_unchecked(xcb_window_t);
+uint32_t window_state_get_reply(xcb_get_property_cookie_t);
+void window_configure(xcb_window_t, area_t, int);
+void window_buttons_grab(xcb_window_t, button_array_t *);
+double window_opacity_get(xcb_window_t);
+void window_opacity_set(xcb_window_t, double);
+void window_grabbuttons(xcb_window_t, xcb_window_t, button_array_t *);
+void window_takefocus(xcb_window_t);
+bool window_hasproto(xcb_window_t, xcb_atom_t);
+void window_setfocus(xcb_window_t, bool);
 
 #endif
 // vim: filetype=c:expandtab:shiftwidth=4:tabstop=8:softtabstop=4:encoding=utf-8:textwidth=80
